
$D = [System.DirectoryServices.ActiveDirectory.Domain]::GetCurrentDomain()
$D1 = $d.name

param  
(  
      $domain = "$d1"  
)  
  

## ==================================================================================  
## Title       : Find All Servers in a Domain With SQL  
## Description : Get a listing of all servers in a domain, test the connection  
##               then check the registry for MS SQL Server Info.  
##                 Output(ServerName, InstanceName, Version and Edition).  
##                 Assumes that instances of MS SQL Server can be found under:  
##                 HKEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Microsoft SQL Server\Instance Names  
## Author      : C.Perry  
## Date        : 10/2/2012  
## Input       : -domain <fully.qualified.domainname>      
## Output      : List of SQL Server names  
## Usage       : PS> . FindAllServersWithSQL.ps1 -domain dev.construction.enet  
## Notes       :  
## Tag           : SQL Server, test-connection, ping, AD, WMI  
## Change log  :  
## ==================================================================================  
# INITIALIZATION SECTION  
cls  
  
# Domain context  
#$domain = $null  
#$domain="<domainName>"  
  
# Initialize variables and files  
$dom = $null  
$ErrorActionPreference = "Continue"  
$found = $null  
$InstNameskey = "SOFTWARE\Microsoft\Microsoft SQL Server\Instance Names"  
$RegInstNameKey = $null  
$MSSQLkey = "SOFTWARE\Microsoft\Microsoft SQL Server"  
$notfound = $null  
#Output file goes into directory you execute from  
$outfile = "$domain" + "_Servers_out.csv"   
$reg = $null  
$regInstance = $null  
$regInstanceData = $null  
$regKey = $null  
$root = $null  
$SetupVersionKey = $null  
$SQLServerkey = $null  
$sbky = $null  
$sub = $null  
$type = [Microsoft.Win32.RegistryHive]::LocalMachine  
"Server, Instance, Version, Edition" #| Out-File $outfile  
# Domain Initalization  
# create the domain context object  
$context = new-object System.DirectoryServices.ActiveDirectory.DirectoryContext("domain",$domain)  
# get the domain object  
$dom = [system.directoryservices.activedirectory.domain]::GetDomain($context)  
# Debug line #$dom   
# go to the root of the Domain  
$root = $dom.GetDirectoryEntry()  
#create the AD Directory Searcher object  
$searcher = new-object System.DirectoryServices.DirectorySearcher($root)  
#filter for all servers that do not start with "wde"  
$filter="(&(objectClass=Computer)(operatingSystem=Windows Server*) (!cn=wde*))"  
$searcher.filter = $filter  
# By default, an Active Directory search returns only 1000 items.  
# If your domain includes 1001 items, then that last item will not be returned.  
# The way to get around that issue is to assign a value to the PageSize property.   
# When you do that, your search script will return (in this case) the first 1,000 items,   
# pause for a split second, then return the next 1,000.   
# This process will continue until all the items meeting the search criteria have been returned.  
$searcher.pageSize=1000  
$colProplist = "name"  

#foreach ($j in $colPropList){$searcher.PropertiesToLoad.Add($j)}  
# get all matching computers  
$colResults = $searcher.FindAll()  

  
# PROCESS Section  
 #interate through all found servers  
foreach ($objResult in $colResults)  
{#Begin ForEach  
    $objItem = $objResult.Properties 
    $objItem.name 
}

