# Get all interactive sessions (including Terminal Server sessions)
$InteractiveSessions = Get-WmiObject Win32_LogonSession -Filter "LogonType = 2 OR LogonType = 10"

foreach ($Session in $InteractiveSessions) {
	$Object = "" | Select-Object Account,Domain,UserName,SessionId,SessionName,LogonId,AuthenticationPackage,Type,Status,ServerName,StartTime
	$Object.PSObject.TypeNames.Insert(0,"System.Management.Automation.PSCustomObject#LocalSession")
	
	$LogonIdFragment = "*`"" + $Session.LogonId + "`""
	
	# Get SessionId from running processes
	$SessionProcessLinks = Get-WmiObject Win32_SessionProcess  | Where-Object {
		$_.Antecedent -ilike $LogonIdFragment
	}
	if ($SessionProcessLinks) {
		$SessionProcessLink = @($SessionProcessLinks)[0]
		
		$Process = [wmi]$SessionProcessLink.Dependent
		
		$Object.SessionId = $Process.SessionId
	} else {
		# Session is not active
		continue
	}
	
	# Set basic session properties
	$Object.ServerName = $env:COMPUTERNAME
	$Object.LogonId = $Session.LogonId
	$Object.AuthenticationPackage = $Session.AuthenticationPackage
	if ($Session.LogonType -eq 2) {
		$Object.Type = "Interactive"
	} elseif ($Session.LogonType -eq 10) {
		$Object.Type = "RemoteInteractive"
	}
	$Object.StartTime = [System.Management.ManagementDateTimeConverter]::ToDateTime($Session.StartTime)
	
	# Get session user
	$SessionUserLink = Get-WmiObject Win32_LoggedOnUser | Where-Object {
		$_.Dependent -ilike $LogonIdFragment
	}
	if ($SessionUserLink) {
		[Void]($SessionUserLink.Antecedent -match '.*Win32_Account.Domain="(.*)",Name="(.*)".*')
		$Account = Get-WmiObject Win32_Account -Filter "Domain = '$($Matches[1])' AND Name = '$($Matches[2])'"
		$Object.Account = $Account.Domain + '\' + $Account.Name
		$Object.Domain = $Account.Domain
		$Object.UserName = $Account.Name
	}
		
	# Get session status and name
	$StatusText = qwinsta.exe $Object.SessionId | Where-Object {$_ -match $Object.SessionId}
	$Object.SessionName = $StatusText -replace "^[> ]([^\s]*).*$",'$1'
	$Object.Status = $StatusText -replace "^.*$($Object.SessionID)  ([^\s]*).*",'$1'
	if ($Object.Status -eq "Disc") {$Object.Status = "Disconnected"}
	
	# Output session
	$rdp = $Object
}


foreach($item in $rdp) 
{ 
"Account : {0}`nDomain : {1}`nUser : {2}`nSession ID : {3}`nSession Name : {4}`nLogin ID : {5}`nType : {6}`nStatus : {7}`nServer Name : {8}`nStart Time : {9}" -f "$($item.Account)", "$($item.Domain)", "$($item.UserName)", "$($item.SessionID)", "$($item.SessionName)", "$($item.LogonId)", "$($item.Type)", "$($item.Status)", "$($item.ServerName)", "$($item.StartTime)"
}

